Module: Google::Cloud::Deploy
- Defined in:
- lib/google/cloud/deploy.rb,
lib/google/cloud/deploy/version.rb
Constant Summary collapse
- VERSION =
"0.1.1"
Class Method Summary collapse
-
.cloud_deploy(version: :v1, &block) ⇒ CloudDeploy::Client
Create a new client object for CloudDeploy.
-
.configure {|::Google::Cloud.configure.deploy| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-deploy library.
Class Method Details
.cloud_deploy(version: :v1, &block) ⇒ CloudDeploy::Client
Create a new client object for CloudDeploy.
By default, this returns an instance of
Google::Cloud::Deploy::V1::CloudDeploy::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the CloudDeploy service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About CloudDeploy
CloudDeploy service creates and manages Continuous Delivery operations on Google Cloud Platform via Skaffold (https://skaffold.dev).
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/google/cloud/deploy.rb', line 67 def self.cloud_deploy version: :v1, &block require "google/cloud/deploy/#{version.to_s.downcase}" package_name = Google::Cloud::Deploy .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::Deploy.const_get package_name package_module.const_get(:CloudDeploy).const_get(:Client).new(&block) end |
.configure {|::Google::Cloud.configure.deploy| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-deploy library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
106 107 108 109 110 |
# File 'lib/google/cloud/deploy.rb', line 106 def self.configure yield ::Google::Cloud.configure.deploy if block_given? ::Google::Cloud.configure.deploy end |